use warnings;
use strict;
use Carp;

BEGIN { require 't/.lib.t' }
plan tests => 13;

my ($sign, $signed_by);

init_gpg_homedir();

throws_ok { gpg_detachsign()                    } qr/Usage/;
throws_ok { gpg_detachsign(0, 0, 0)             } qr/Usage/;
throws_ok { gpg_detachsign(undef)               } qr/undefined/;
throws_ok { gpg_detachsign(q{})                 } qr/no default secret key/;
throws_ok { gpg_detachsign('junk', [])          } qr/no default secret key/;

gpg_import($SEC_KEY{ $KEY_ID[0] }, 1);
lives_ok  { gpg_detachsign(q{}, [])             } 'empty msg signed';
lives_ok  { gpg_detachsign(q{}, [$KEY_ID[0]])   } 'empty msg signed';
lives_ok  { $sign = gpg_detachsign(q{})         } 'empty msg signed';
$signed_by = gpg_verify(q{}, $sign);
is_deeply($signed_by, { $KEY_ID[0] => 1 },        '  signature correct');
throws_ok { gpg_verify('junk', $sign)           } qr/BAD signature/;

throws_ok { gpg_detachsign(q{}, [$KEY_ID[1]])   } qr/secret key not available/;

gpg_import($SEC_KEY{ $KEY_ID[1] }, 1);
lives_ok  { $sign = gpg_detachsign('test', [$KEY_ID[1]])
                                                } 'test msg signed';
delete_secret_and_public($KEY_ID[1]);
$signed_by = gpg_verify('test', $sign);
is_deeply($signed_by, { $LONGKEY_ID[1] => 0 },    '  signature not checked');

